@@ -1,13 +1,13 @@
 from bpython import formatter
-from termformatconstants import FG_COLORS, BG_COLORS, colors
-from fmtstr import fmtstr
+from .termformatconstants import FG_COLORS, BG_COLORS, colors
+from .fmtstr import fmtstr
 
 from functools import partial
 
 import re
 
 
-cnames = dict(zip('krgybmcwd', colors + ('default',)))
+cnames = dict(list(zip('krgybmcwd', colors + ('default',))))
 
 def func_for_letter(l, default='k'):
     if l == 'd':
@@ -47,7 +47,7 @@ def fs_from_match(d):
             atts['fg'] = FG_COLORS[color]
     if d['bg']:
         if d['bg'] == 'I':
-            color = colors[(colors.index(color) + (len(colors)/2)) % len(colors)] # hack for finding the "inverse"
+            color = colors[(colors.index(color) + (len(colors) // 2)) % len(colors)] # hack for finding the "inverse"
         else:
             color = cnames[d['bg'].lower()]
         if color != 'default':
@@ -96,9 +96,9 @@ def test():
 
     all_tokens = list(PythonLexer().get_tokens('print 1 + 2'))
     formatted_line = format(all_tokens, BPythonFormatter(config.color_scheme))
-    print(repr(formatted_line))
+    print((repr(formatted_line)))
     fs = parse(formatted_line)
-    print(repr(fs))
+    print((repr(fs)))
     print(fs)
 
     string_to_fmtstr('asdf')
